@@ -51,6 +51,22 @@ class TrajOneOutcomeOneRep:
         self.times = np.array(times)
         self.obss = np.array(observations)
 
+    def get_t_index_passing_threshold(self, threshold):
+        """
+        :param threshold: (float) the threshold where observations should reach
+        :return: (int) the time index when the threshold is reach for the first time
+        """
+
+        if_reached = False
+        t = 0
+        while not if_reached:
+            if self.obss[t] >= threshold:
+                if_reached = True
+            else:
+                t += 1
+
+        return t
+
 
 class TrajsOneOutcomeMultipleReps:
     # trajectories for one simulation outcome from multiple simulation replications
@@ -90,7 +106,7 @@ class TrajsOneOutcomeMultipleReps:
 
     def get_mean_PI(self, time_index, alpha=0.05, multiplier=1, deci=0, form=None):
         """
-        :param time_index: (int) time index at which mean and percentile interval should be calcualted
+        :param time_index: (int) time index at which mean and percentile interval should be calculated
         :param alpha: (float) confidence level
         :param multiplier: to multiply the estimate and the interval by the provided value
         :param deci: digits to round the numbers to
@@ -107,6 +123,31 @@ class TrajsOneOutcomeMultipleReps:
             return stat.get_formatted_mean_and_interval(
                 interval_type='p', deci=deci, form=form, multiplier=multiplier)
 
+    def get_mean_PI_time_to_threshold(self, threshold, alpha=0.05, multiplier=1, deci=0, form=None):
+        """
+        :param threshold: (float) the threshold where observations should reach
+        :param alpha: (float) confidence level
+        :param multiplier: to multiply the estimate and the interval by the provided value
+        :param deci: digits to round the numbers to
+        :param form: ',' to format as number, '%' to format as percentage, and '$' to format as currency
+        :return: the mean and percentile interval of time until a threshold is reached
+        """
+
+        print('THIS NEEDS TO BE DEBUGGED.')
+
+        obss = []
+        for traj in self.trajs:
+            obss.append(traj.get_t_index_passing_threshold(threshold=threshold))
+
+        # find the estimate and percentile interval
+        stat = Stat.SummaryStat(name='', data=obss)
+
+        if form is None:
+            return stat.get_mean(), stat.get_PI(alpha)
+        else:
+            return stat.get_formatted_mean_and_interval(
+                interval_type='p', deci=deci, form=form, multiplier=multiplier)
+
     def get_relative_diff_mean_PI(self, time_index0, time_index1, order=0, deci=0, form=None):
         """
         :param time_index0: first time index
@@ -117,15 +158,15 @@ class TrajsOneOutcomeMultipleReps:
         :return: the mean relative difference of trajectories at two time indeces
         """
         stat = Stat.RelativeDifferencePaired(
-            '',
+            name='',
             x=self.get_obss(time_index1),
             y_ref=self.get_obss(time_index0),
             order=order)
 
-        if format is None:
+        if form is None:
             return stat.get_mean(), stat.get_PI(alpha=0.05)
         else:
-            return stat.get_formatted_mean_and_interval(interval_type='p', alpha=0.05, deci=deci, form=format)
+            return stat.get_formatted_mean_and_interval(interval_type='p', alpha=0.05, deci=deci, form=form)
 
     def get_trajs_mean(self):
         """
